@@ -27,6 +27,7 @@
 #include <QRegularExpression>
 #include <QStandardPaths>
 #include <QTimer>
+#include <kwidgetsaddons_version.h>
 
 using namespace Akonadi;
 
@@ -36,9 +37,7 @@ ImportMailJobInterface::ImportMailJobInterface(QObject *parent, Utils::StoredTyp
     initializeImportJob();
 }
 
-ImportMailJobInterface::~ImportMailJobInterface()
-{
-}
+ImportMailJobInterface::~ImportMailJobInterface() = default;
 
 void ImportMailJobInterface::start()
 {
@@ -74,7 +73,12 @@ void ImportMailJobInterface::slotNextStep()
             slotNextStep();
         }
     } else {
-        Q_EMIT jobFinished();
+        // Reapply attribute at the end (after resource syncing)
+        if (mListStep.contains(Utils::Mails)) {
+            importFolderAttributes();
+        } else {
+            Q_EMIT jobFinished();
+        }
     }
 }
 
@@ -167,19 +171,24 @@ void ImportMailJobInterface::restoreTransports()
     increaseProgressDialog();
     const QString path = Utils::transportsPath() + QStringLiteral("mailtransports");
     if (!mFileList.contains(path)) {
-        Q_EMIT error(i18n("mailtransports file could not be found in the archive."));
+        emitError(i18n("mailtransports file could not be found in the archive."));
     } else {
-        Q_EMIT info(i18n("Restore transports..."));
+        emitInfo(i18n("Restore transports..."));
 
         const KArchiveEntry *transport = mArchiveDirectory->entry(path);
+        bool importDone = false;
         if (transport && transport->isFile()) {
             const auto fileTransport = static_cast<const KArchiveFile *>(transport);
 
-            copyArchiveFileTo(fileTransport, mTempDirName);
-            importMailTransport(mTempDirName);
-            Q_EMIT info(i18n("Transports restored."));
+            importDone = copyArchiveFileTo(fileTransport, mTempDirName);
+            if (importDone) {
+                importMailTransport(mTempDirName);
+            }
+        }
+        if (importDone) {
+            emitInfo(i18n("Transports restored."));
         } else {
-            Q_EMIT error(i18n("Failed to restore transports file."));
+            emitError(i18n("Failed to restore transports file."));
         }
     }
     QTimer::singleShot(0, this, &ImportMailJobInterface::slotNextStep);
@@ -189,11 +198,12 @@ void ImportMailJobInterface::restoreResources()
 {
     increaseProgressDialog();
     setProgressDialogLabel(i18n("Restore resources..."));
-    Q_EMIT info(i18n("Restore resources..."));
+    emitInfo(i18n("Restore resources..."));
 
     QDir dir(mTempDirName);
     dir.mkdir(Utils::resourcesPath());
     ResourceConverterImpl converter;
+    QStringList listResourceToSync;
     for (const QString &filename : std::as_const(mFileList)) {
         // We need to find akonadi_* and agent_config_akonadi_*
         if (filename.startsWith(Utils::resourcesPath() + QStringLiteral("akonadi_"))) {
@@ -295,10 +305,11 @@ void ImportMailJobInterface::restoreResources()
                         settings.insert(QStringLiteral("DownloadLater"), leaveOnserver.readEntry("downloadLater", QStringList()));
                     }
                     const QString newResourceName = resourceName.isEmpty() ? filename : resourceName;
-                    const QString newResource = createResource(QStringLiteral("akonadi_pop3_resource"), newResourceName, settings);
+                    const QString newResource = createResource(QStringLiteral("akonadi_pop3_resource"), newResourceName, settings, false);
                     if (!newResource.isEmpty()) {
                         mHashResources.insert(filename, newResource);
                         infoAboutNewResource(newResource);
+                        listResourceToSync << newResource;
                     }
                 } else if (filename.contains(QLatin1String("imap")) || filename.contains(QLatin1String("kolab_"))
                            || filename.contains(QLatin1String("gmail_"))) {
@@ -394,15 +405,16 @@ void ImportMailJobInterface::restoreResources()
                     QString newResource;
                     const QString newResourceName = resourceName.isEmpty() ? filename : resourceName;
                     if (filename.contains(QLatin1String("kolab_"))) {
-                        newResource = createResource(QStringLiteral("akonadi_kolab_resource"), newResourceName, settings);
+                        newResource = createResource(QStringLiteral("akonadi_kolab_resource"), newResourceName, settings, true);
                     } else if (filename.contains(QLatin1String("gmail_"))) {
-                        newResource = createResource(QStringLiteral("akonadi_gmail_resource"), newResourceName, settings);
+                        newResource = createResource(QStringLiteral("akonadi_gmail_resource"), newResourceName, settings, true);
                     } else {
-                        newResource = createResource(QStringLiteral("akonadi_imap_resource"), newResourceName, settings);
+                        newResource = createResource(QStringLiteral("akonadi_imap_resource"), newResourceName, settings, true);
                     }
                     if (!newResource.isEmpty()) {
                         mHashResources.insert(filename, newResource);
                         infoAboutNewResource(newResource);
+                        listResourceToSync << newResource;
                     }
                 } else {
                     qCWarning(PIMDATAEXPORTERCORE_LOG) << " problem with resource: " << filename;
@@ -410,10 +422,13 @@ void ImportMailJobInterface::restoreResources()
             }
         }
     }
-    // TODO synctree ?
+    emitInfo(i18n("Resources restored."));
+    synchronizeResource(listResourceToSync);
+}
 
-    Q_EMIT info(i18n("Resources restored."));
-    QTimer::singleShot(0, this, &ImportMailJobInterface::slotNextStep);
+QString ImportMailJobInterface::applicationName() const
+{
+    return QStringLiteral("[KMail]");
 }
 
 void ImportMailJobInterface::restoreMails()
@@ -421,7 +436,7 @@ void ImportMailJobInterface::restoreMails()
     increaseProgressDialog();
     setProgressDialogLabel(i18n("Restore mails..."));
     QStringList listResourceToSync;
-    Q_EMIT info(i18n("Restore mails..."));
+    emitInfo(i18n("Restore mails..."));
 
     QDir dir(mTempDirName);
     dir.mkdir(Utils::mailsPath());
@@ -494,7 +509,7 @@ void ImportMailJobInterface::restoreMails()
                         settings.insert(QStringLiteral("MessageCount"), compacting.readEntry(QStringLiteral("MessageCount"), 50));
                     }
                 }
-                const QString newResource = createResource(QStringLiteral("akonadi_mbox_resource"), filename, settings);
+                const QString newResource = createResource(QStringLiteral("akonadi_mbox_resource"), filename, settings, true);
                 if (!newResource.isEmpty()) {
                     mHashResources.insert(filename, newResource);
                     infoAboutNewResource(newResource);
@@ -517,7 +532,8 @@ void ImportMailJobInterface::restoreMails()
                     createResource(resourceName.contains(QLatin1String("akonadi_mixedmaildir_resource_")) ? QStringLiteral("akonadi_mixedmaildir_resource")
                                                                                                           : QStringLiteral("akonadi_maildir_resource"),
                                    filename,
-                                   settings);
+                                   settings,
+                                   true);
                 if (!newResource.isEmpty()) {
                     mHashResources.insert(filename, newResource);
                     infoAboutNewResource(newResource);
@@ -537,7 +553,7 @@ void ImportMailJobInterface::restoreMails()
             // qCDebug(PIMDATAEXPORTERCORE_LOG)<<"url "<<url;
         }
     }
-    Q_EMIT info(i18n("Mails restored."));
+    emitInfo(i18n("Mails restored."));
     synchronizeResource(listResourceToSync);
 }
 
@@ -547,10 +563,11 @@ void ImportMailJobInterface::restoreConfig()
     setProgressDialogLabel(i18n("Restore config..."));
     const QString filtersPath(Utils::configsPath() + QStringLiteral("filters"));
     if (!mFileList.contains(filtersPath)) {
-        Q_EMIT error(i18n("filters file could not be found in the archive."));
+        emitError(i18n("filters file could not be found in the archive."));
     } else {
         const KArchiveEntry *filter = mArchiveDirectory->entry(filtersPath);
         if (filter && filter->isFile()) {
+            emitInfo(i18n("Restore filters..."));
             const auto fileFilter = static_cast<const KArchiveFile *>(filter);
 
             copyArchiveFileTo(fileFilter, mTempDirName);
@@ -599,6 +616,7 @@ void ImportMailJobInterface::restoreConfig()
             }
             filtersConfig->sync();
             importFilters(filterFileName);
+            emitInfo(i18n("Filters restored."));
         }
     }
     const QString kmailsnippetrcStr(QStringLiteral("kmailsnippetrc"));
@@ -624,9 +642,17 @@ void ImportMailJobInterface::restoreConfig()
             const QString kabldaprc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + labldaprcStr;
             if (QFileInfo::exists(kabldaprc)) {
                 const int result = mergeConfigMessageBox(labldaprcStr);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (result == KMessageBox::Yes) {
+#endif
                     copyToFile(kabldap, kabldaprc, labldaprcStr, Utils::configsPath());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                } else if (result == KMessageBox::ButtonCode::SecondaryAction) {
+#else
                 } else if (result == KMessageBox::No) {
+#endif
                     mergeLdapConfig(kabldap, labldaprcStr, Utils::configsPath());
                 }
             } else {
@@ -643,9 +669,17 @@ void ImportMailJobInterface::restoreConfig()
                 QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + archiveconfigurationrcStr;
             if (QFileInfo::exists(archiveconfigurationrc)) {
                 const int result = mergeConfigMessageBox(archiveconfigurationrcStr);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (result == KMessageBox::Yes) {
+#endif
                     importArchiveConfig(archiveconfiguration, archiveconfigurationrc, archiveconfigurationrcStr, Utils::configsPath());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                } else if (result == KMessageBox::ButtonCode::SecondaryAction) {
+#else
                 } else if (result == KMessageBox::No) {
+#endif
                     mergeArchiveMailAgentConfig(archiveconfiguration, archiveconfigurationrcStr, Utils::configsPath());
                 }
             } else {
@@ -662,9 +696,17 @@ void ImportMailJobInterface::restoreConfig()
             const QString archiveconfigurationrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + folderMailArchiveStr;
             if (QFileInfo::exists(archiveconfigurationrc)) {
                 const int result = mergeConfigMessageBox(folderMailArchiveStr);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (result == KMessageBox::Yes) {
+#endif
                     importMailArchiveConfig(archiveconfiguration, archiveconfigurationrc, folderMailArchiveStr, Utils::configsPath());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                } else if (result == KMessageBox::ButtonCode::SecondaryAction) {
+#else
                 } else if (result == KMessageBox::No) {
+#endif
                     mergeMailArchiveConfig(archiveconfiguration, folderMailArchiveStr, Utils::configsPath());
                 }
             } else {
@@ -681,9 +723,17 @@ void ImportMailJobInterface::restoreConfig()
             const QString unifiedMailBoxrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + unifiedMailBoxStr;
             if (QFileInfo::exists(unifiedMailBoxrc)) {
                 const int result = mergeConfigMessageBox(unifiedMailBoxStr);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (result == KMessageBox::Yes) {
+#endif
                     importUnifiedMailBoxConfig(archiveconfiguration, unifiedMailBoxrc, unifiedMailBoxStr, Utils::configsPath());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                } else if (result == KMessageBox::ButtonCode::SecondaryAction) {
+#else
                 } else if (result == KMessageBox::No) {
+#endif
                     mergeUnifiedMailBoxConfig(archiveconfiguration, unifiedMailBoxStr, Utils::configsPath());
                 }
             } else {
@@ -731,9 +781,17 @@ void ImportMailJobInterface::restoreConfig()
         const QString sievetemplaterc = configLocation() + sievetemplatercStr;
         if (QFileInfo::exists(sievetemplaterc)) {
             const int result = mergeConfigMessageBox(sievetemplatercStr);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (result == KMessageBox::Yes) {
+#endif
                 copyToFile(sievetemplateconfiguration, sievetemplaterc, sievetemplatercStr, Utils::configsPath());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            } else if (result == KMessageBox::ButtonCode::SecondaryAction) {
+#else
             } else if (result == KMessageBox::No) {
+#endif
                 mergeSieveTemplate(sievetemplateconfiguration, sievetemplatercStr, Utils::configsPath());
             }
         } else {
@@ -846,7 +904,7 @@ void ImportMailJobInterface::restoreConfig()
     importDataSubdirectory(QStringLiteral("/messageviewer/themes/"));
     importDataSubdirectory(QStringLiteral("/messageviewerplugins/"));
 
-    Q_EMIT info(i18n("Config restored."));
+    emitInfo(i18n("Config restored."));
     QTimer::singleShot(0, this, &ImportMailJobInterface::slotNextStep);
 }
 
@@ -882,9 +940,9 @@ void ImportMailJobInterface::restoreIdentity()
     setProgressDialogLabel(i18n("Restoring identities..."));
     const QString path(Utils::identitiesPath() + QStringLiteral("emailidentities"));
     if (!mFileList.contains(path)) {
-        Q_EMIT error(i18n("emailidentities file could not be found in the archive."));
+        emitError(i18n("emailidentities file could not be found in the archive."));
     } else {
-        Q_EMIT info(i18n("Restoring identities..."));
+        emitInfo(i18n("Restoring identities..."));
         const KArchiveEntry *identity = mArchiveDirectory->entry(path);
         if (identity && identity->isFile()) {
             const auto fileIdentity = static_cast<const KArchiveFile *>(identity);
@@ -943,9 +1001,9 @@ void ImportMailJobInterface::restoreIdentity()
                 const QString name = group.readEntry(QStringLiteral("Identity"));
                 addNewIdentity(name, group, defaultIdentity, oldUid);
             }
-            Q_EMIT info(i18n("Identities restored."));
+            emitInfo(i18n("Identities restored."));
         } else {
-            Q_EMIT error(i18n("Failed to restore identity file."));
+            emitError(i18n("Failed to restore identity file."));
         }
     }
     QTimer::singleShot(0, this, &ImportMailJobInterface::slotNextStep);
@@ -1092,7 +1150,11 @@ void ImportMailJobInterface::importTemplatesConfig(const KArchiveFile *templates
         // Identity
         if (str.startsWith(templateGroupIdentityPattern)) {
             bool found = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const int identity = str.rightRef(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
+#else
+            const int identity = QStringView(str).right(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
+#endif
             if (found) {
                 KConfigGroup oldGroup = templateConfig->group(str);
                 if (mHashIdentity.contains(identity)) {
@@ -1263,6 +1325,7 @@ void ImportMailJobInterface::importKmailConfig(const KArchiveFile *kmailsnippet,
     }
 
     kmailConfig->sync();
+    emitInfo(i18n("\"%1\" migration done.", filename));
 }
 
 void ImportMailJobInterface::mergeLdapConfig(const KArchiveFile *archivefile, const QString &filename, const QString &prefix)
