@@ -30,7 +30,7 @@ PimDataExporterKernel::PimDataExporterKernel(QObject *parent)
     : QObject(parent)
 {
     mIdentityManager = KIdentityManagement::IdentityManager::self();
-    Akonadi::Session *session = new Akonadi::Session("Backup Mail Kernel ETM", this);
+    auto session = new Akonadi::Session("Backup Mail Kernel ETM", this);
 
     mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor(session, this);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KContacts::Addressee::mimeType(), true);
@@ -109,7 +109,7 @@ qreal PimDataExporterKernel::closeToQuotaThreshold()
 QStringList PimDataExporterKernel::customTemplates()
 {
     Q_ASSERT(false);
-    return QStringList();
+    return {};
 }
 
 bool PimDataExporterKernel::excludeImportantMailFromExpiry()
